CoreCommand

Struct CoreCommand 

pub struct CoreCommand {
    pub surface: RuntimeSurface,
    pub action: CoreAction,
    pub snapshot: BrowserSnapshot,
}
A command sent from JavaScript to the Rust core.

This is the only entry point into the core’s state machine. JavaScript adapters construct this from user actions and browser state.

Fields

surface: RuntimeSurface

Which surface sent this command.

action: CoreAction

What action to perform.

snapshot: BrowserSnapshot

Current browser state snapshot.